<?php
if (!defined('ABSPATH')) {
	exit;
}
?>
<meta property="og:type" content="<?php echo (is_singular() ? 'article' : 'website'); ?>">
<?php
$post_id = get_the_ID();
$og_description = $og_title = $og_url = $excerpt = '';

if (is_singular()) {

	if (have_posts()) : while (have_posts()) : the_post();

			if (has_excerpt($post_id)) {

				$excerpt = @nmd_get_the_excerpt_outside($post_id);
				
			} else {

				$excerpt = @nmd_get_excerpt(140, $post_id);
			}

		endwhile;
	endif;

	$og_description = $excerpt;
	$og_title = get_the_title();
	$og_url = get_permalink();

	if (is_front_page()) {

		$og_title = NMD_BLOG_NAME;
	}

	$update_time = get_the_modified_date('YmdHis');
} elseif (is_category()) {
	/**
	 * カテゴリーページ
	 */
	$cat_id = get_query_var('cat');
	$cat_meta = get_option('cat_' . $cat_id);

	$cat = get_the_category();
	$cat = $cat[0];

	if (!empty($category_description = category_description())) {

		$og_description = nmd_sanitize_excerpt($category_description, true);
	} elseif (!empty($cat_meta["meta-description"])) {

		$cat_meta_description = $cat_meta["meta-description"];
		$og_description = nmd_delete_breaks($cat_meta_description);
	} else {
		$og_description = '「' . $cat->name . '」カテゴリーの記事一覧 | ' . NMD_BLOG_NAME;
	}

	$og_title = '「' . $cat->name . '」カテゴリーの記事一覧 | ' . NMD_BLOG_NAME;
	$og_url = get_category_link($cat_id);
} elseif (is_tag()) {
	/**
	 * タグページ
	 */
	$tag_id = get_query_var('tag_id');
	$tags = get_tag($tag_id);

	$title = '「' . $tags->name . '」タグの記事一覧 | ' . NMD_BLOG_NAME;
	$og_description = $title;
	$og_title = $title;
	$og_url = get_tag_link($tag_id);
} elseif (is_author()) {
	/**
	 * 投稿者ページ
	 */
	$author_id = get_the_author_meta('ID');
	$author_name = get_the_author_meta('display_name');

	$og_title = $author_name . 'の記事一覧 | ' . NMD_BLOG_NAME;
	$og_description = $author_name . 'の記事一覧 | ' . NMD_BLOG_NAME;
	$og_url = get_author_posts_url($author_id);
} else {

	$og_description = NMD_BLOG_DESCRIPTION;
	$og_title = NMD_BLOG_NAME;
	$og_url = NMD_HOME_URL;
}

echo '<meta property="og:description" content="' . $og_description . '">' . "\n";
echo '<meta property="og:title" content="' . $og_title . '">' . "\n";
echo '<meta property="og:url" content="' . $og_url . '">' . "\n";

$theme_default_image_url = NMD_TEMPLATE_URI . '/assets/img/no-image/no-image.png';
$default_thumbnail_url = nmd_get_the_customizer_image_url('nmd_default_thumbnail');
$top_page_ogp_image_url = nmd_get_the_customizer_image_url('nmd_top_page_ogp_image');


/**
 * og:imageの設定
 */
if (is_singular()) {
	/**
	 * 投稿・固定ページの場合
	 */
	if (has_post_thumbnail()) {

		$image_id = get_post_thumbnail_id();
		$image = wp_get_attachment_image_src($image_id, 'full');

		echo '<meta property="og:image" content="' . $image[0] . '?' . $update_time . '">' . "\n";
	} elseif ($default_thumbnail_url) {
		/**
		 * デフォルトの画像が設定されている場合
		 */
		echo '<meta property="og:image" content="' . $default_thumbnail_url . '?' . $update_time . '">' . "\n";
	} elseif ($top_page_ogp_image_url) {
		/**
		 * トップページのOGP画像が設定されている場合
		 */
		echo '<meta property="og:image" content="' . $top_page_ogp_image_url . '?' . $update_time . '">' . "\n";
	} else {
		/**
		 * 何もなければテーマに入っている画像を設定
		 */
		echo '<meta property="og:image" content="' . $theme_default_image_url . '?' . $update_time . '">' . "\n";
	}
} elseif ($top_page_ogp_image_url) {
	/**
	 * トップページのOGP画像が設定されている場合
	 */
	echo '<meta property="og:image" content="' . $top_page_ogp_image_url . '">' . "\n";
} elseif ($default_thumbnail_url) {
	/**
	 * デフォルトの画像が設定されている場合
	 */
	echo '<meta property="og:image" content="' . $default_thumbnail_url . '">' . "\n";
} else {
	/**
	 * 何もなければテーマに入っている画像を設定
	 */
	echo '<meta property="og:image" content="' . $theme_default_image_url . '">' . "\n";
}
?>
<meta property="og:site_name" content="<?php bloginfo('name'); ?>">
<meta property="og:locale" content="ja_JP">
