<?php
/**
 * カスタマイザーの設定
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if( !function_exists( 'nmd_customizer_register_seo' ) ) {
	function nmd_customizer_register_seo( $wp_customize ) {
		/**
		 * SEOパネル ======================================================
		 */
		$wp_customize->add_panel( 'nmd_seo_panel', array(
			'title'		=> '[Nomad]SEO関連の設定',
			'priority'	=> 190,
		));
		/**
		 * タイトルの設定
		 */
		$wp_customize->add_section( 'nmd_section_title', array(
			'title'       => 'タイトルの設定',
			'panel'       => 'nmd_seo_panel',
			'priority'    => 10,
			'description' => '検索結果やブラウザのタブなどで表示されるタイトルの設定ができます。'
		) );
		$wp_customize->add_setting( 'nmd_top_title', array(
			'type'              => 'option',
			'default'           => 'sitename_tagline',
			'sanitize_callback' => 'nmd_sanitize_select',
		) );
		$wp_customize->add_control( 'nmd_top_title', array(
			'label'       => 'トップページのタイトル',
			'description' => 'トップページのタイトル形式を設定できます',
			'section'     => 'nmd_section_title',
			'settings'    => 'nmd_top_title',
			'type'        => 'select',
			'choices'     => array(
				'sitename_tagline' => 'サイト名 - キャッチフレーズ',
				'sitename_only'    => 'サイト名',
			),
		) );

		$wp_customize->add_setting( 'nmd_lowerpage_title', array(
			'type'              => 'option',
			'default'           => 'title_sitename',
			'sanitize_callback' => 'nmd_sanitize_select',
		) );
		$wp_customize->add_control( 'nmd_lowerpage_title', array(
			'label'       => 'トップページ以外のタイトル',
			'description' => 'トップページ以外のタイトル形式を設定できます',
			'section'     => 'nmd_section_title',
			'settings'    => 'nmd_lowerpage_title',
			'type'        => 'select',  
			'choices'     => array(
				'title_sitename'         => 'ページのタイトル - サイト名',
				'title_sitename_tagline' => 'ページのタイトル - サイト名 - キャッチフレーズ',
				'title_only'             => 'ページタイトルのみ',
			),
		) );
		/**
		 * metaタグの設定
		 */
		$wp_customize->add_section( 'section_meta', array(
			'title'       => 'metaタグの設定',
			'panel'       => 'nmd_seo_panel',
			'priority'    => 10,
			'description' => 'metaタグに関する設定です。'
		) );
		// トップページのmeta description
		$wp_customize->add_setting( 'nmd_top_meta_description', array(
			'type'              => 'option',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'nmd_top_meta_description', array(
			'settings'      => 'nmd_top_meta_description',
			'section'       => 'section_meta',
			'label'         => 'トップページのmeta description',
			'description'   => 'トップページのmeta descriptionを設定します。<br>検索結果に表示される文章です。',
			'type'          => 'textarea',
		) );

		/**
		 * インデックスに関する設定
		 */
		$wp_customize->add_section( 'nmd_section_index', array(
			'title'       => 'インデックスに関する設定',
			'panel'       => 'nmd_seo_panel',
			'priority'    => 20,
			'description' => 'canonical、noindex、nofollowの設定を行います。'
		) );

		// canonical
		$wp_customize->add_setting( 'nmd_setting_canonical', array(
			'default'           => 'checked',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'nmd_setting_canonical', array(
			'settings'    => 'nmd_setting_canonical',
			'section'     => 'nmd_section_index',
			'label'       => 'canonicalを自動で挿入する',
			'description' => 'ここでチェックを外しても、投稿ページで個別に設定することもできます。',
			'type'        => 'checkbox',
		) );
		// カテゴリーページ
		$wp_customize->add_setting( 'nmd_index_category_title', array(
			'sanitize_callback' => 'nmd_no_sanitize',
		) );
		$wp_customize->add_control( new Nmd_Custom_Heading( $wp_customize, 'nmd_index_category_title', array(
			'section' => 'nmd_section_index',
			'label'   => 'カテゴリーページのnoindex,nofollow',
		) ) );
		$wp_customize->add_setting( 'nmd_setting_index_category', array(
			'type'              => 'option',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control('nmd_setting_index_category', array(
			'settings'    => 'nmd_setting_index_category',
			'section'     => 'nmd_section_index',
			'label'       => 'カテゴリーページをnoindexにする',
			'description' => 'カテゴリーページはGoogle検索結果から外されます。',
			'type'        => 'checkbox',
		) );
		$wp_customize->add_setting( 'nmd_setting_follow_category', array(
			'type'              => 'option',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control('nmd_setting_follow_category', array(
			'settings'    => 'nmd_setting_follow_category',
			'section'     => 'nmd_section_index',
			'label'       => 'カテゴリーページをnofollowにする',
			'type'        => 'checkbox',
		) );

		// タグページ index
		$wp_customize->add_setting( 'nmd_index_tagpage_title', array(
			'sanitize_callback' => 'nmd_no_sanitize',
		) );
		$wp_customize->add_control( new Nmd_Custom_Heading( $wp_customize, 'nmd_index_tagpage_title', array(
			'section' => 'nmd_section_index',
			'label'   => 'タグページのnoindex,nofollow',
		) ) );
		$wp_customize->add_setting( 'nmd_setting_index_tags', array(
			'type'              => 'option',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control('nmd_setting_index_tags', array(
			'settings'    => 'nmd_setting_index_tags',
			'section'     => 'nmd_section_index',
			'label'       => 'タグページをnoindexにする',
			'description' => 'タグページはGoogle検索結果から外されます。',
			'type'        => 'checkbox',
		) );
		$wp_customize->add_setting( 'nmd_setting_follow_tags', array(
			'type'              => 'option',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control('nmd_setting_follow_tags', array(
			'settings'    => 'nmd_setting_follow_tags',
			'section'     => 'nmd_section_index',
			'label'       => 'タグページをnofollowにする',
			'type'        => 'checkbox',
		) );

		// 日別・月別・年別ページ index
		$wp_customize->add_setting( 'nmd_index_date_title', array(
			'sanitize_callback' => 'nmd_no_sanitize',
		) );
		$wp_customize->add_control( new Nmd_Custom_Heading( $wp_customize, 'nmd_index_date_title', array(
			'section' => 'nmd_section_index',
			'label'   => '日別、月別、年別ページのnoindex,nofollow',
		) ) );
		$wp_customize->add_setting( 'nmd_setting_index_date', array(
			'type'              => 'option',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control('nmd_setting_index_date', array(
			'settings'		=> 'nmd_setting_index_date',
			'section'		=> 'nmd_section_index',
			'label'			=> '日別、月別、年別ページをnoindexにする',
			'description'	=> '日別、月別、年別ページはGoogle検索結果から外されます。',
			'type'			=> 'checkbox',
		) );
		$wp_customize->add_setting( 'nmd_setting_follow_date', array(
			'type'				=> 'option',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'nmd_setting_follow_date', array(
			'settings'    => 'nmd_setting_follow_date',
			'section'     => 'nmd_section_index',
			'label'       => '日別、月別、年別ページをnofollowにする',
			'type'        => 'checkbox',
		) );

		// 検索結果ページ index
		$wp_customize->add_setting( 'nmd_index_search_title', array(
			'sanitize_callback' => 'nmd_no_sanitize',
		) );
		$wp_customize->add_control( new Nmd_Custom_Heading( $wp_customize, 'nmd_index_search_title', array(
			'section' => 'nmd_section_index',
			'label'   => '検索結果ページのnoindex,nofollow',
		) ) );
		$wp_customize->add_setting( 'nmd_setting_index_search', array(
			'type' => 'option',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'nmd_setting_index_search', array(
			'settings'    => 'nmd_setting_index_search',
			'section'     => 'nmd_section_index',
			'label'       => '検索結果ページをnoindexにする',
			'description' => '検索結果ページはGoogle検索結果から外されます。',
			'type'        => 'checkbox',
		) );
		$wp_customize->add_setting( 'nmd_setting_follow_search', array(
			'type' => 'option',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'nmd_setting_follow_search', array(
			'settings'	=> 'nmd_setting_follow_search',
			'section'	=> 'nmd_section_index',
			'label'		=> '検索結果ページをnofollowにする',
			'type'		=> 'checkbox',
		) );

		// 投稿者別記事一覧ページ index
		$wp_customize->add_setting( 'nmd_index_author_page_title', array(
			'sanitize_callback' => 'nmd_no_sanitize',
		) );
		$wp_customize->add_control( new Nmd_Custom_Heading( $wp_customize, 'nmd_index_author_page_title', array(
			'section' => 'nmd_section_index',
			'label'   => '投稿者別記事一覧ページのnoindex,nofollow',
		) ) );
		$wp_customize->add_setting( 'nmd_setting_index_author_page', array(
			'type'				=> 'option',
			'sanitize_callback'	=> 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'nmd_setting_index_author_page', array(
			'settings'		=> 'nmd_setting_index_author_page',
			'section'		=> 'nmd_section_index',
			'label'			=> '投稿者別記事一覧ページをnoindexにする',
			'description'	=> '投稿者別記事一覧ページはGoogle検索結果から外されます。',
			'type'			=> 'checkbox',
		) );
		$wp_customize->add_setting( 'nmd_setting_follow_author_page', array(
			'type'				=> 'option',
			'sanitize_callback'	=> 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'nmd_setting_follow_author_page', array(
			'settings'	=> 'nmd_setting_follow_author_page',
			'section'	=> 'nmd_section_index',
			'label'		=> '投稿者別記事一覧ページをnofollowにする',
			'type'		=> 'checkbox',
		) );
	
		/**
		 * パブリッシャーの設定
		 */
		$wp_customize->add_section( 'nmd_section_publisher', array(
			'title'       => 'JSON-LDのパブリッシャー設定',
			'panel'       => 'nmd_seo_panel',
			'priority'    => 210,
			'description' => 'JSON-LDで使用するパブリッシャーの設定をします。下記の項目は必須事項。'
		) );
		$wp_customize->add_setting( 'nmd_publisher_name', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'nmd_publisher_name', array(
			'label'       => 'パブリッシャーの「name」',
			'description' => 'JSON-LDで使用するパブリッシャーの「name」を設定。サイト運営者や組織の名前を入力さしてください。',
			'section'     => 'nmd_section_publisher',
			'settings'    => 'nmd_publisher_name',
			'type'        => 'text',
		) );

		$wp_customize->add_setting( 'nmd_publisher_image', array(
			'type' => 'option',
			'sanitize_callback' => 'nmd_slug_sanitize_image',
		) );
		$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'nmd_publisher_image', array(
			'label'       => 'パブリッシャーの「logo」',
			'description' => 'JSON-LDで使用するパブリッシャーの「logo」を設定をします。サイト運営者や組織のロゴ画像。',
			'section'     => 'nmd_section_publisher',
			'settings'    => 'nmd_publisher_image',
		) ) );
	
		
		/**
		 * アクセス解析の設定
		 */
		$wp_customize->add_section( 'nmd_section_access_analysis', array(
			'title'       => 'アクセス解析設定',
			'panel'       => 'nmd_seo_panel',
			'priority'    => 220,
			'description' => 'アクセス解析設定を行います。プラグインで設定している場合は空欄にしてください。'
		) );
		// Google Analytics
		$wp_customize->add_setting( 'nmd_setting_analytics', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'nmd_setting_analytics', array(
			'settings'    => 'nmd_setting_analytics',
			'section'     => 'nmd_section_access_analysis',
			'label'       => 'Google Analyticsのタグを挿入',
			'description' => '例：G-xxxxxxxxxx、もしくは UA-xxxxxxx-xx',
			'type'        => 'text',
		) );
		$wp_customize->add_setting( 'nmd_no_count_login_user', array(
			'type' => 'option',
			'sanitize_callback' => 'nmd_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'nmd_no_count_login_user', array(
			'settings'    => 'nmd_no_count_login_user',
			'section'     => 'nmd_section_access_analysis',
			'label'       => 'ログイン中は計測しない',
			'description' => 'ログインしているユーザーをアナリティクスで計測しないように設定します。',
			'type'        => 'checkbox',
		) );
		// Google Search Console
		$wp_customize->add_setting( 'nmd_setting_search_console', array(
			'type' => 'option',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control('nmd_setting_search_console', array(
			'settings'    => 'nmd_setting_search_console',
			'section'     => 'nmd_section_access_analysis',
			'label'       => 'Search Consoleのタグを挿入',
			'description' => 'content="この中の文字列を入力"',
			'type'        => 'text',
		) );
	}
	add_action( 'customize_register', 'nmd_customizer_register_seo' );
}
