<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if( !function_exists( 'nmd_customizer_register_top' ) ) {
	function nmd_customizer_register_top( $wp_customize ) {
		/**
		 * パネルの追加 =========================================================
		 */
		$wp_customize->add_panel( 'nmd_toppage_panel', array(
            'title'    => '[Nomad]トップページの設定',
            'priority' => 190,
		));
		/**
		 * ヘッダー画像のテキスト =========================================================
		 */
		$wp_customize->add_section('nmd_section_header_image', array(
			'title'       => 'ヘッダー画像のテキスト',
			'panel'       => 'nmd_toppage_panel',
		));
		// テキストタイプ
		$wp_customize->add_setting('nmd_header_image_text_type', array(
			'type'				=> 'option',
			'sanitize_callback' => 'nmd_sanitize_select',
			'default'			=> 'title',
		));
		$wp_customize->add_control('nmd_header_image_text_type', array(
			'label'			=> 'ヘッダー画像にのせるテキスト',
			'section'		=> 'nmd_section_header_image',
			'settings'		=> 'nmd_header_image_text_type',
			'type'			=> 'radio',
			'choices'	=> array(
				'title'		=> 'サイトタイトル',
				'custom'	=> 'カスタム',
				'none'		=> 'テキストなし',
			),
		));
		$wp_customize->selective_refresh->add_partial('nmd_header_image_text_type', array(
			'selector' => '#c-mv-title',
		));
		// カスタムテキスト
		$wp_customize->add_setting('nmd_header_image_text', array(
			'type'				=> 'option',
			'sanitize_callback' => 'nmd_sanitize_html_available_br',
		));
		$wp_customize->add_control('nmd_header_image_text', array(
			'label'			=> 'カスタムを選んだ場合はこちらにテキストを入力してください。<br>タグが使えます。',
			'section'		=> 'nmd_section_header_image',
			'settings'		=> 'nmd_header_image_text',
			'type'			=> 'text',
		));

		$wp_customize->add_setting( 'nmd_header_image_font_size_heading', array(
			'sanitize_callback' => 'nmd_no_sanitize',
		) );
		$wp_customize->add_control( new Nmd_Custom_Heading( $wp_customize, 'nmd_header_image_font_size_heading', array(
			'section' => 'nmd_section_header_image',
			'label'   => 'テキストのフォントサイズ',
		) ) );

		$wp_customize->add_setting('nmd_header_image_font_size', array(
			'type' => 'option',
			'default' => '40',
			'sanitize_callback' => 'nmd_sanitize_number_range',
		));
		$wp_customize->add_control('nmd_header_image_font_size', array(
			'label'       => 'フォントサイズ（PC）',
			'description' => '16~60pxの範囲で設定できます。',
			'section'     => 'nmd_section_header_image',
			'settings'    => 'nmd_header_image_font_size',
			'type'        => 'number',
			'input_attrs' => array(
				'step' => '1',
				'min'  => '16',
				'max' => '60'
			),
		));
		$wp_customize->add_setting('nmd_header_image_font_size_sp', array(
			'type' => 'option',
			'default' => '20',
			'sanitize_callback' => 'nmd_sanitize_number_range',
		));
		$wp_customize->add_control('nmd_header_image_font_size_sp', array(
			'label'       => 'フォントサイズ（スマホ）',
			'description' => '14~40pxの範囲で設定できます。',
			'section'     => 'nmd_section_header_image',
			'settings'    => 'nmd_header_image_font_size_sp',
			'type'        => 'number',
			'input_attrs' => array(
				'step' => '1',
				'min'  => '14',
				'max' => '40'
			),
		));

		/**
		 * スライドショー =========================================================
		 */
		$wp_customize->add_section( 'nmd_section_carousel', array(
			'title'       => 'スライドショー',
			'panel'       => 'nmd_toppage_panel',
			'description' => 'トップページに表示するスライドショーの設定'
		) );
		$wp_customize->add_setting( 'nmd_carousel_entry_id', array(
			'type'				=> 'option',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'nmd_carousel_entry_id', array(
			'label'			=> 'スライドショー',
			'description'	=> 'スライドショーに表示する記事IDをコンマ区切りで記述してください。<br>例：1,5,12',
			'section'		=> 'nmd_section_carousel',
			'settings'		=> 'nmd_carousel_entry_id',
			'type'			=> 'text',
		) );
		$wp_customize->selective_refresh->add_partial( 'nmd_carousel_entry_id', array(
			'selector' => '#carousel',
		) );

		/**
		 * 全幅スライダー =========================================================
		 */
		$wp_customize->add_section( 'nmd_section_slider', array(
			'title'       => '全幅スライダー',
			'panel'       => 'nmd_toppage_panel',
			'description' => 'トップページに表示する全幅スライダーの設定'
		) );
		$wp_customize->add_setting( 'nmd_slider_entry_id', array(
			'type'				=> 'option',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'nmd_slider_entry_id', array(
			'label'			=> '全幅スライダー',
			'description'	=> '全幅スライダーに表示する記事IDをコンマ区切りで記述してください。<br>例：1,5,12',
			'section'		=> 'nmd_section_slider',
			'settings'		=> 'nmd_slider_entry_id',
			'type'			=> 'text',
		) );
		$wp_customize->selective_refresh->add_partial( 'nmd_slider_entry_id', array(
			'selector' => '#pickup',
		) );

		/**
		 * 記事一覧のタイトル =========================================================
		 */
		$wp_customize->add_section('nmd_section_entries_title', array(
			'title'       => __('記事一覧のタイトル', NMD_TEXT_DOMAIN),
			'panel'       => 'nmd_toppage_panel',
			'description' => __('トップページ記事一覧のタイトル', NMD_TEXT_DOMAIN),
		));
		$wp_customize->add_setting('nmd_entries_title_top', array(
			'type'				=> 'option',
			'sanitize_callback' => 'sanitize_text_field',
			'default'			=> __('新着記事', NMD_TEXT_DOMAIN),
		));
		$wp_customize->add_control('nmd_entries_title_top', array(
			'label'			=> __('記事一覧のタイトル', NMD_TEXT_DOMAIN),
			'description'	=> __('トップページ記事一覧のタイトル', NMD_TEXT_DOMAIN),
			'section'		=> 'nmd_section_entries_title',
			'settings'		=> 'nmd_entries_title_top',
			'type'			=> 'text',
		));
		$wp_customize->selective_refresh->add_partial('nmd_entries_title_top', array(
			'selector' => '#entries-ttl-top',
		));
		$wp_customize->add_setting('nmd_entries_title', array(
			'type'				=> 'option',
			'sanitize_callback' => 'sanitize_text_field',
			'default'			=> __('記事一覧', NMD_TEXT_DOMAIN),
		));
		$wp_customize->add_control('nmd_entries_title', array(
			'label'			=> __('2ページ目以降のタイトル', NMD_TEXT_DOMAIN),
			'description'	=> __('記事一覧2ページ目以降のタイトル', NMD_TEXT_DOMAIN),
			'section'		=> 'nmd_section_entries_title',
			'settings'		=> 'nmd_entries_title',
			'type'			=> 'text',
		));
		$wp_customize->selective_refresh->add_partial('nmd_entries_title', array(
			'selector' => '#entries-ttl',
		));

		/**
		 * 指定カテゴリーの新着記事 =========================================================
		 */
		$wp_customize->add_section( 'nmd_section_category_latest', array(
			'title'       => '指定カテゴリーの新着記事',
			'panel'       => 'nmd_toppage_panel',
			'description' => 'トップページに指定カテゴリーの新着記事を表示させます'
		) );
		$wp_customize->add_setting( 'nmd_category_latest_ids', array(
			'type'				=> 'option',
			'sanitize_callback' => 'sanitize_text_field',
		) );
		$wp_customize->add_control( 'nmd_category_latest_ids', array(
			'label'			=> 'カテゴリーID',
			'description'	=> 'カテゴリーIDをコンマ区切りで記述してください。<br>例：1,5,12',
			'section'		=> 'nmd_section_category_latest',
			'settings'		=> 'nmd_category_latest_ids',
			'type'			=> 'text',
		) );
	}
	add_action( 'customize_register', 'nmd_customizer_register_top' );
}