<?php

/**
 * 投稿画面SEO設定メタボックス
 */
if (!defined('ABSPATH')) {
	exit;
}

//カスタムフィールドの追加
if (!function_exists('nmd_add_seo_custom_boxes')) {

	function nmd_add_seo_custom_boxes()
	{
		add_meta_box('seo_setting', __('SEO設定', NMD_TEXT_DOMAIN), 'nmd_seo_custom_box', 'post', 'normal');
		add_meta_box('seo_setting', __('SEO設定', NMD_TEXT_DOMAIN), 'nmd_seo_custom_box', 'page', 'normal');
	}
	if (empty(get_option('nmd_invalidation_post_settings')))
		add_action('admin_menu', 'nmd_add_seo_custom_boxes');
}

function nmd_seo_custom_box()
{
	$post_id = get_the_ID();
	$seo_title = get_post_meta($post_id, 'seo_title', true);
	$seo_title = htmlspecialchars($seo_title);
	$meta_description = get_post_meta($post_id, 'meta_description', true);
	$meta_description = htmlspecialchars($meta_description);
	$meta_keywords = get_post_meta($post_id, 'meta_keywords', true);
	$meta_keywords = htmlspecialchars($meta_keywords);
	$is_noindex = get_post_meta($post_id, 'is_noindex', true);
	$is_nofollow = get_post_meta($post_id, 'is_nofollow', true);
	$custom_canonical = get_post_meta($post_id, 'custom_canonical', true);
	$custom_canonical = htmlspecialchars($custom_canonical);

	wp_nonce_field('wp-nonce-key', '_wp_nonce_nmd');
?>

	<p><?php _e('SEO用の設定。入力は任意です。入力がない場合は自動的に設定されます。', NMD_TEXT_DOMAIN); ?></p>
	<!-- SEOタイトル -->
	<label style="font-weight:bold;margin-bottom:4px;display:inline-block;">SEOタイトル</label>
	<input type="text" id="seo-title" name="seo_title" value="<?php echo $seo_title ?>" style="width:100%;padding:4px;" placeholder="タイトルを入力してください。" />
	<p style="margin:4px 0 24px;color:#666;">※SEO対策用のタイトルを設定して下さい。</p>
	<!-- メタディスクリプション -->
	<label style="font-weight:bold;margin-bottom:4px;display:inline-block;">メタディスクリプション</label>
	<textarea id="meta-description" name="meta_description" style="width:100%;padding:4px;height: 4em;" placeholder="説明文を入力してください。"><?php echo $meta_description; ?></textarea>
	<p style="margin:4px 0 24px;color:#666">※記事のメタディスクリプションを設定して下さい。検索結果に表示される文言で、記事の内容がざっくり分かるようにしましょう。120文字前後が表示されます。短すぎると目立ちません。</p>
	<!-- メタキーワード -->
	<label style="font-weight:bold;margin-bottom:4px;display:inline-block;">メタキーワード</label>
	<input type="text" id="meta-keywords" name="meta_keywords" value="<?php echo $meta_keywords; ?>" style="width:100%;padding:4px;" placeholder="キーワードを入力してください。" />
	<p style="margin:4px 0 24px;color:#666">※メタキーワードを設定して下さい。キーワードを半角のカンマ（,）で区切って下さい。あまり重要な項目ではありません。</p>
	<!-- canonical -->
	<label style="font-weight:bold;margin-bottom:4px;display:inline-block;">カスタムcanonical</label>
	<input type="text" id="custom-canonical" name="custom_canonical" value="<?php echo $custom_canonical; ?>" style="width:100%;padding:4px;" placeholder="canonicalに設定するURLを入れて下さい。" />
	<p style="margin:4px 0 24px;color:#666">※基本は空欄で大丈夫です。中身が同じ・ほぼ同じページが複数ある場合に優先的にインデックスして欲しいURLを設定します。URLを間違えないように注意してください。</p>
	<!-- noindex -->
	<label style="font-weight:bold"><input type="checkbox" value="noindex" name="is_noindex" <?php if ($is_noindex) {
																									echo " checked";
																								} ?>>noindex</label>
	<p style="margin:4px 0 24px;color:#666">このページが検索エンジンにインデックスされないようにします。中身のない低品質なページは、noindexにすることをおすすめします。</p>

	<!-- nofollow -->
	<label style="font-weight:bold"><input type="checkbox" value="nofollow" name="is_nofollow" <?php if ($is_nofollow) {
																									echo " checked";
																								} ?>>nofollow</label>
	<p style="margin:4px 0 24px;color:#666">このページにあるリンクを検索エンジンにフォローされないようにします。</p>
<?php
}

// 入力された値をメタデータとして格納
if (!function_exists('nmd_save_seo_custom_data')) {
	function nmd_save_seo_custom_data()
	{

		if (!isset($_POST['_wp_nonce_nmd']) || !$_POST['_wp_nonce_nmd']) return;
		if (!check_admin_referer('wp-nonce-key', '_wp_nonce_nmd')) return;

		$id = get_the_ID();

		//タイトル
		$seo_title = null;
		$seo_title_key = 'seo_title';

		if (isset($_POST['seo_title']) && $_POST['seo_title'] === '') {
			delete_post_meta($id, $seo_title_key);
		} elseif (!empty($_POST['seo_title'])) {
			$seo_title = $_POST['seo_title'];
			add_post_meta($id, $seo_title_key, $seo_title, true);
			update_post_meta($id, $seo_title_key, $seo_title);
		}

		//メタディスクリプション
		$meta_description = null;
		$meta_description_key = 'meta_description';

		if (isset($_POST['meta_description']) && $_POST['meta_description'] === '') {
			delete_post_meta($id, $meta_description_key);
		} elseif (!empty($_POST['meta_description'])) {
			$meta_description = $_POST['meta_description'];
			add_post_meta($id, $meta_description_key, $meta_description, true);
			update_post_meta($id, $meta_description_key, $meta_description);
		}

		//メタキーワード
		$meta_keywords = null;
		$meta_keywords_key = 'meta_keywords';

		if (isset($_POST['meta_keywords']) && $_POST['meta_keywords'] === '') {
			delete_post_meta($id, $meta_keywords_key);
		} elseif (!empty($_POST['meta_keywords'])) {
			$meta_keywords = $_POST['meta_keywords'];
			add_post_meta($id, $meta_keywords_key, $meta_keywords, true);
			update_post_meta($id, $meta_keywords_key, $meta_keywords);
		}

		//メタキーワード
		$custom_canonical = null;
		$custom_canonical_key = 'custom_canonical';

		if (isset($_POST['custom_canonical']) && $_POST['custom_canonical'] === '') {
			delete_post_meta($id, $custom_canonical_key);
		} elseif (!empty($_POST['custom_canonical'])) {
			$custom_canonical = $_POST['custom_canonical'];
			add_post_meta($id, $custom_canonical_key, $custom_canonical, true);
			update_post_meta($id, $custom_canonical_key, $custom_canonical);
		}

		//noindex
		$is_noindex = null;
		$is_noindex_key = 'is_noindex';

		if (isset($_POST['is_noindex'])) {
			$is_noindex = $_POST['is_noindex'];
			add_post_meta($id, $is_noindex_key, $is_noindex, true);
			update_post_meta($id, $is_noindex_key, $is_noindex);
		} else {
			delete_post_meta($id, $is_noindex_key);
		}

		//nofollow
		$is_nofollow = null;
		$is_nofollow_key = 'is_nofollow';
		if (isset($_POST['is_nofollow'])) {
			$is_nofollow = $_POST['is_nofollow'];
			add_post_meta($id, $is_nofollow_key, $is_nofollow, true);
			update_post_meta($id, $is_nofollow_key, $is_nofollow);
		} else {
			delete_post_meta($id, $is_nofollow_key);
		}
	}
	add_action('save_post', 'nmd_save_seo_custom_data');
}
